@@ -589,10 +589,6 @@ class TypeArray(TypeAny):#{{{
                 "One subtype should be set for array type"
         
         has_missing = dims[0].has_missing or has_missing
-        if self.__class__ == TypeArray:
-            assert not has_missing, "Array type not allowed to have missing values"
-        
-        dims[0].has_missing = has_missing
         self.subtypes = subtypes
         self.dims = dims
         TypeAny.__init__(self, has_missing)
@@ -616,10 +612,16 @@ class TypeArray(TypeAny):#{{{
         return res
 
     def setHasMissing(self, value):
-        s = self.subtypes[0].setHasMissing(value)
-        if not s is self.subtypes[0]:
+        if value and not self.dims[0].dependent: #fixed dim, needs has_missing subtype if unpacked
+            s = self.subtypes[0].setHasMissing(value)
+        else:
+            s = self.subtypes[0]
+            
+        if not self.has_missing == value or not s is self.subtypes[0]:
             self = self.copy()
+            self.has_missing = value
             self.subtypes = (s,)
+            
         return self
 
 
@@ -912,6 +914,12 @@ class TypeString(TypeArray):#{{{
         if(self.dims[0].shape >= 0):
             res += '[' + str(self.dims[0].shape) + ']'
         return res
+
+
+    def toDefval(self):
+        """Returns default value."""
+        return ""
+
 addType(TypeString)#}}}
 
 class TypeBytes(TypeString):#{{{
@@ -1739,7 +1747,7 @@ class TypeStringASTInterpreter(object):#{{{
             dim = self.dims[name]
             if(len(dim.dependent) > dimpos):
                 raise RuntimeError, "Dim: " + name + " has too many dependent dims: " + str(len(dim.dependent)) + " (max: " + str(dimpos) + ")"
-            if dim.shape != shape and not shape == UNDEFINED and not dim.shape == UNDEFINED:
+            if dim.shape != shape and not shape is None and not shape == UNDEFINED and not dim.shape == UNDEFINED:
                 raise RuntimeError, "Dim: " + name + " dimension unequal to known dim"
 
             return dim
