@@ -191,8 +191,8 @@ class Filter(repops.MultiOpRep):
         else:
             assert seldimpath, "Filter dimpath is empty"
 
-            #if(cslice.dims and isinstance(cslice.type,rtypes.TypeInteger)):
-            #    cslice = ops.PackArrayOp(cslice)
+            if(cslice.dims and isinstance(cslice.type,rtypes.TypeInteger)):
+                cslice = ops.PackArrayOp(cslice)
 
             if(isinstance(cslice.type, rtypes.TypeInteger)):
                 ndim = None
