@@ -224,9 +224,9 @@ class Representor(Node):
             #print self.__str__(False)
             return [slice.name for slice in self._slices]
 
-    def Copy(self):
+    def Copy(self, log=False, debug=False):
         res = wrapper.SourceRepresentor()
-        res._initialize(tuple(self._getResultSlices(endpoint=False)))
+        res._initialize(tuple(self._getResultSlices(endpoint=False, log=log, debug=debug)))
         return res
 
    
@@ -345,12 +345,15 @@ class Representor(Node):
             condition = context._apply(condition, self)
         return repops_multi.Filter(self, condition, dim) 
 
-    def _getResultSlices(self, args={}, endpoint=True):
+    def _getResultSlices(self, args={}, endpoint=True, log=False, debug=False):
         query = query_context.QueryContext(self, args, endpoint)
-        return tuple(engines.select_engine.run(query))
+        if debug:
+            return tuple(engines.debug_engine.run(query, log))
+        else:
+            return tuple(engines.select_engine.run(query, log))
 
     def __call__(self, **args):
-        res = self._getResultSlices(args)
+        res = self._getResultSlices(**args)
 
         if(len(res) == 1):
             return res[0].data
@@ -769,9 +772,9 @@ class Representor(Node):
     def TakeFrom(self, other, allow_missing=False,keep_missing=False):
         return repops_multi.Take(other, self, allow_missing,keep_missing)
 
-    def ToPython(self):
+    def ToPython(self, **args):
         """Converts data into python data structure"""
-        return repops_slice.ToPythonRep(self)()
+        return repops_slice.ToPythonRep(self)(**args)
 
     def Sort(self, *slices, **kwargs):
         """Performs sort on data.
